@@ -179,56 +179,22 @@ void TagLibExtractorTest::testCommonData_data()
 {
     QTest::addColumn<QString>("fileType");
 
-    QTest::addRow("aiff")
-        << QStringLiteral("aif")
-        ;
-
-    QTest::addRow("ape")
-        << QStringLiteral("ape")
-        ;
-
-    QTest::addRow("flac")
-        << QStringLiteral("flac")
-        ;
-
-    QTest::addRow("flac+ogg")
-        << QStringLiteral("flac.ogg")
-        ;
-
-    QTest::addRow("m4a")
-        << QStringLiteral("m4a")
-        ;
-
+    // clang-format: off
+    QTest::addRow("aiff")      << QStringLiteral("aif");
+    QTest::addRow("ape")       << QStringLiteral("ape");
+    QTest::addRow("flac")      << QStringLiteral("flac");
+    QTest::addRow("flac+ogg")  << QStringLiteral("flac.ogg");
+    QTest::addRow("m4a")       << QStringLiteral("m4a");
     QTest::addRow("mp3 id3v2") << QStringLiteral("mp3") ;
     QTest::addRow("mp3 id3v1") << QStringLiteral("id3v1.mp3");
-
-    QTest::addRow("mpc")
-        << QStringLiteral("mpc")
-        ;
-
-    QTest::addRow("ogg")
-        << QStringLiteral("ogg")
-        ;
-
-    QTest::addRow("opus")
-        << QStringLiteral("opus")
-        ;
-
-    QTest::addRow("speex")
-        << QStringLiteral("spx")
-        ;
-
-    QTest::addRow("wav")
-        << QStringLiteral("wav")
-        ;
-
-    QTest::addRow("wavpack")
-        << QStringLiteral("wv")
-        ;
-
-    QTest::addRow("wma")
-        << QStringLiteral("wma")
-        ;
+    QTest::addRow("mpc")       << QStringLiteral("mpc");
+    QTest::addRow("ogg")       << QStringLiteral("ogg");
+    QTest::addRow("opus")      << QStringLiteral("opus");
+    QTest::addRow("speex")     << QStringLiteral("spx");
+    QTest::addRow("wav")       << QStringLiteral("wav");
+    QTest::addRow("wavpack")   << QStringLiteral("wv");
+    QTest::addRow("wma")       << QStringLiteral("wma");
+    // clang-format: on
 }
 
 void TagLibExtractorTest::testVorbisComment()
@@ -272,25 +238,13 @@ void TagLibExtractorTest::testVorbisComment_data()
 {
     QTest::addColumn<QString>("fileType");
 
-    QTest::addRow("flac")
-        << QStringLiteral("flac")
-        ;
-
-    QTest::addRow("flac+ogg")
-        << QStringLiteral("flac.ogg")
-        ;
-
-    QTest::addRow("ogg")
-        << QStringLiteral("ogg")
-        ;
-
-    QTest::addRow("opus")
-        << QStringLiteral("opus")
-        ;
-
-    QTest::addRow("speex")
-        << QStringLiteral("spx")
-        ;
+    // clang-format: off
+    QTest::addRow("flac")     << QStringLiteral("flac");
+    QTest::addRow("flac+ogg") << QStringLiteral("flac.ogg");
+    QTest::addRow("ogg")      << QStringLiteral("ogg");
+    QTest::addRow("opus")     << QStringLiteral("opus");
+    QTest::addRow("speex")    << QStringLiteral("spx");
+    // clang-format: on
 }
 
 void TagLibExtractorTest::testVorbisCommentMultivalue()
@@ -750,57 +704,21 @@ void TagLibExtractorTest::testImageData_data()
 {
     QTest::addColumn<QString>("fileName");
 
-    QTest::addRow("aiff")
-            << QStringLiteral("test.aif")
-            ;
-
-    QTest::addRow("ape")
-            << QStringLiteral("test.ape")
-            ;
-
-    QTest::addRow("opus")
-            << QStringLiteral("test.opus")
-            ;
-
-    QTest::addRow("ogg")
-            << QStringLiteral("test.ogg")
-            ;
-
-    QTest::addRow("flac")
-            << QStringLiteral("test.flac")
-            ;
-
-    QTest::addRow("flac+ogg")
-        << QStringLiteral("test.flac.ogg")
-        ;
-
-    QTest::addRow("mp3")
-        << QStringLiteral("test.mp3")
-        ;
-
-    QTest::addRow("m4a")
-            << QStringLiteral("test.m4a")
-            ;
-
-    QTest::addRow("mpc")
-            << QStringLiteral("test.mpc")
-            ;
-
-    QTest::addRow("speex")
-            << QStringLiteral("test.spx")
-            ;
-
-    QTest::addRow("wav")
-            << QStringLiteral("test.wav")
-            ;
-
-    QTest::addRow("wavpack")
-            << QStringLiteral("test.wv")
-            ;
-
-    QTest::addRow("wma")
-            << QStringLiteral("test.wma")
-            ;
+    // clang-format: off
+    QTest::addRow("aiff")     << QStringLiteral("test.aif");
+    QTest::addRow("ape")      << QStringLiteral("test.ape");
+    QTest::addRow("opus")     << QStringLiteral("test.opus");
+    QTest::addRow("ogg")      << QStringLiteral("test.ogg");
+    QTest::addRow("flac")     << QStringLiteral("test.flac");
+    QTest::addRow("flac+ogg") << QStringLiteral("test.flac.ogg");
+    QTest::addRow("mp3")      << QStringLiteral("test.mp3");
+    QTest::addRow("m4a")      << QStringLiteral("test.m4a");
+    QTest::addRow("mpc")      << QStringLiteral("test.mpc");
+    QTest::addRow("speex")    << QStringLiteral("test.spx");
+    QTest::addRow("wav")      << QStringLiteral("test.wav");
+    QTest::addRow("wavpack")  << QStringLiteral("test.wv");
+    QTest::addRow("wma")      << QStringLiteral("test.wma");
+    // clang-format: on
 }
 
 void TagLibExtractorTest::testModuleTrackerFormats()
